diff --git a/osu.Game.Rulesets.Taiko/Difficulty/Skills/Stamina.cs b/osu.Game.Rulesets.Taiko/Difficulty/Skills/Stamina.cs
index 32d8b70485..61bcbfa59d 100644
--- a/osu.Game.Rulesets.Taiko/Difficulty/Skills/Stamina.cs
+++ b/osu.Game.Rulesets.Taiko/Difficulty/Skills/Stamina.cs
@@ -20,26 +20,27 @@ namespace osu.Game.Rulesets.Taiko.Difficulty.Skills
protected override double SkillMultiplier => 1;
protected override double StrainDecayBase => 0.4;
- ///
- /// Stamina of each individual keys, calculated based on repetition speed.
- ///
- private readonly SingleKeyStamina[] keyStamina =
+ private readonly SingleKeyStamina[] centreKeyStamina =
{
new SingleKeyStamina(),
- new SingleKeyStamina(),
+ new SingleKeyStamina()
+ };
+
+ private readonly SingleKeyStamina[] rimKeyStamina =
+ {
new SingleKeyStamina(),
new SingleKeyStamina()
};
///
/// Current index to for a don hit.
///
- private int donIndex = 1;
+ private int centreKeyIndex;
///
/// Current index to for a kat hit.
///
- private int katIndex = 3;
+ private int rimKeyIndex;
///
/// Creates a skill.
@@ -59,12 +60,12 @@ namespace osu.Game.Rulesets.Taiko.Difficulty.Skills
// Alternate key for the same color.
if (current.HitType == HitType.Centre)
{
- donIndex = donIndex == 0 ? 1 : 0;
- return keyStamina[donIndex];
+ centreKeyIndex = (centreKeyIndex + 1) % 2;
+ return centreKeyStamina[centreKeyIndex];
}
- katIndex = katIndex == 2 ? 3 : 2;
- return keyStamina[katIndex];
+ rimKeyIndex = (rimKeyIndex + 1) % 2;
+ return rimKeyStamina[rimKeyIndex];
}
protected override double StrainValueOf(DifficultyHitObject current)
@@ -20,26 +20,27 @@ namespace osu.Game.Rulesets.Taiko.Difficulty.Skills
};
///
- /// Current index to for a don hit.
+ /// Current index into for a centre hit.
///
@@ -20,26 +20,27 @@ namespace osu.Game.Rulesets.Taiko.Difficulty.Skills
///
- /// Current index to for a kat hit.
+ /// Current index into for a rim hit.
///